/*
 * Copyright (C) 2008-2012 FreeIPMI Core Team
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef IPMI_SENSORS_CONFIG_THRESHOLD_SECTION_H
#define IPMI_SENSORS_CONFIG_THRESHOLD_SECTION_H

#include "ipmi-sensors-config.h"
#include "ipmi-sensors-config-sections.h"

config_err_t
ipmi_sensors_config_threshold_section (ipmi_sensors_config_state_data_t *state_data,
                                       struct config_section **section_ptr);

#endif /* IPMI_SENSORS_CONFIG_THRESHOLD_SECTION_H */
